@@ -29,6 +29,7 @@
 #include <QPainter>
 #include <QStandardItemModel>
 
+#include <KDebug>
 #include <KGlobalSettings>
 #include <KLocale>
 #include <KMessageBox>
@@ -71,9 +72,13 @@ public:
         return m_currentWeather;
     }
 
+    void setIconGuide(QGraphicsWidget *widget)
+    {
+        m_guide = widget;
+    }
+
     void setCurrentWeather(const QString &currentWeather = QString())
     {
-        kDebug() << "!!!!!!!!!!!!!!!!!!!!!!!" << currentWeather;
         if (isValidIconName(currentWeather)) {
             m_currentWeather = KIcon(currentWeather);
         } else {
@@ -90,12 +95,13 @@ public:
         }
 
         QSize s(KIconLoader::SizeEnormous, KIconLoader::SizeEnormous);
-        s.boundedTo(size().toSize());
+        s = s.boundedTo(m_guide ? m_guide.data()->size().toSize() : size().toSize());
         painter->drawPixmap(QPoint(0, 0), m_currentWeather.pixmap(s));
     }
 
 private:
     KIcon m_currentWeather;
+    QWeakPointer<QGraphicsWidget> m_guide;
 };
 
 WeatherApplet::WeatherApplet(QObject *parent, const QVariantList &args)
@@ -191,12 +197,14 @@ void WeatherApplet::init()
     m_titleFrame->setLayout(m_titlePanel);
     m_layout->addItem(m_titleFrame);
 
-    m_courtesyLabel->nativeWidget()->setWordWrap(false);
-    m_courtesyLabel->nativeWidget()->setAlignment(Qt::AlignRight);
     m_courtesyLabel->nativeWidget()->setFont(KGlobalSettings::smallestReadableFont());
+    m_courtesyLabel->setWordWrap(false);
+    m_courtesyLabel->setAlignment(Qt::AlignRight);
+    m_courtesyLabel->setTextSelectable(false);
     connect(m_courtesyLabel, SIGNAL(linkActivated(QString)), this, SLOT(invokeBrowser(QString)));
 
     m_graphicsWidget->setLayout(m_layout);
+    m_graphicsWidget->setIconGuide(m_titleFrame);
 
     WeatherPopupApplet::init();
 }
@@ -360,6 +368,7 @@ void WeatherApplet::weatherContent(const Plasma::DataEngine::Data &data)
         // fiveDayTokens[4] = Low Temperature
         if (fiveDayTokens[4] != "N/A" && fiveDayTokens[3] == "N/A") {  // Low temperature
             m_tempLabel->setText(convertTemperature(temperatureUnit(), data["Temperature"].toString(), data["Temperature Unit"].toInt(), false));
+            m_tempLabel->show(); //m_tempLabel might be hidden if temperature was not available
             m_forecastTemps->setText(i18nc("Low temperature", "Low: %1", convertTemperature(temperatureUnit(), fiveDayTokens[4], data["Temperature Unit"].toInt(), true)));
         } else if (fiveDayTokens[3] != "N/A" && fiveDayTokens[4] == "N/A") { // High temperature
             m_forecastTemps->setText(i18nc("High temperature", "High: %1", convertTemperature(temperatureUnit(), fiveDayTokens[3], data["Temperature Unit"].toInt(), true)));
@@ -375,8 +384,9 @@ void WeatherApplet::weatherContent(const Plasma::DataEngine::Data &data)
 
     if (isValidData(data["Temperature"])) {
         m_tempLabel->setText(convertTemperature(temperatureUnit(), data["Temperature"].toString(), data["Temperature Unit"].toInt(), false));
+        m_tempLabel->show(); //m_tempLabel might be hidden if temperature was not available
     } else {
-        m_tempLabel->setText(i18nc("Not available","N/A"));
+        m_tempLabel->hide(); //temperature is not available (probability the engine doesn't support it)
     }
 
     m_courtesyLabel->setText(data["Credit"].toString());
@@ -737,6 +747,9 @@ void WeatherApplet::weatherContent(const Plasma::DataEngine::Data &data)
         m_tabBar->addTab(i18nc("weather notices", "Notices"), noticeLayout);
     }
 
+    // Hide the tab bar if there is only one tab to show
+    m_tabBar->setTabBarShown(m_tabBar->count() > 1);
+    
     if (!m_setupLayout) {
         m_layout->addItem(m_tabBar);
         m_layout->addItem(m_courtesyLabel);
